summaryrefslogtreecommitdiffstats
path: root/modules/module.go
diff options
context:
space:
mode:
Diffstat (limited to 'modules/module.go')
-rw-r--r--modules/module.go14
1 files changed, 7 insertions, 7 deletions
diff --git a/modules/module.go b/modules/module.go
index a5f707635..c3343c820 100644
--- a/modules/module.go
+++ b/modules/module.go
@@ -30,10 +30,10 @@ type Module interface {
// The decoded module config and mounts.
Config() Config
// Optional configuration filename (e.g. "/themes/mytheme/config.json").
// This will be added to the special configuration watch list when in
// server mode.
- ConfigFilename() string
+ ConfigFilenames() []string
// Directory holding files for this module.
Dir() string
@@ -82,9 +82,9 @@ type moduleAdapter struct {
mounts []Mount
- configFilename string
- cfg config.Provider
- config Config
+ configFilenames []string
+ cfg config.Provider
+ config Config
// Set if a Go module.
gomod *goModule
@@ -98,8 +98,8 @@ func (m *moduleAdapter) Config() Config {
return m.config
}
-func (m *moduleAdapter) ConfigFilename() string {
- return m.configFilename
+func (m *moduleAdapter) ConfigFilenames() []string {
+ return m.configFilenames
}
func (m *moduleAdapter) Dir() string {
@@ -30,10 +30,10 @@ type Module interface {
// The decoded module config and mounts.
Config() Config
- // Optional configuration filename (e.g. "/themes/mytheme/config.json").
+ // Optional configuration filenames (e.g. "/themes/mytheme/config.json").
// This will be added to the special configuration watch list when in
// server mode.